SELECT_ALL = 'SELECT COLUMNS_NAME FROM `TABLE_NAME`'
SELECT_WHERE = 'SELECT COLUMNS_NAME FROM `TABLE_NAME` WHERE {} {} ?'

UPDATE = 'UPDATE `TABLE_NAME` SET {} WHERE {} {} ?'
INSERT = 'INSERT INTO `TABLE_NAME` ({}) VALUES ({})'
DELETE = 'DELETE FROM `TABLE_NAME` WHERE {} {} ?'

ORDER_BY = ' ORDER BY {}'
LIMIT = ' LIMIT {}'
GROUP_BY = ' GROUP BY {}'

SUM = 'SUM({}) as {}'
COUNT = 'COUNT({}) as {}'
